@@ -335,6 +335,17 @@ class MyWhatify:
     def api_patch(cls, url, headers=None, body=None, params=None, user_token=None):
         return APIRequestor().patch(url=url, headers=headers, body=body, params=params, api_key=user_token)
 
+    @classmethod
+    def send_api(cls, url, method, headers=None, body=None, params=None, user_token=None):
+        switcher = {
+            'GET': cls.api_get,
+            'POST': cls.api_post,
+            'Put': cls.api_put,
+            'PATCH': cls.api_patch
+        }
+        func = switcher.get(method.upper(), lambda: "Invalid api method")
+        return func(url=url, headers=headers, body=body, params=params, user_token=user_token)
+
     @classmethod
     def get_data_source(cls, data_name):
         logging.info('getting the DataSource list for data_name: ' + str(data_name))
